Module core

Module core 

A module providing persistent vector types based on RrbTree.

Modules

iter
A module providing implementation of the standard Iterator, as well as Rayon’s ParallelIterator if the rayon_iter feature flag is specified.

Structs

RbVec
A persistent vector based on the balanced RbTree.
RrbVec
A persistent vector based on the relaxed RrbTree.